@@ -4,7 +4,8 @@
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
 set.seed(290875)
-options(prompt = "R> ", width = 63, # digits = 4,
+options(prompt = "R> ", continue = "+  ",
+    width = 63, # digits = 4,
     SweaveHooks = list(leftpar = function()
         par(mai = par("mai") * c(1, 1.05, 1, 1))))
 HSAURpkg <- require("HSAUR")
@@ -13,16 +14,28 @@ rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
 a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
+book <- TRUE
+refs <- cbind(c("AItR", "SI", "CI", "ANOVA", "MLR", "GLM",
+                "DE", "RP", "SA", "ALDI", "ALDII", "MA", "PCA",
+                "MDS", "CA"), 1:15)
+ch <- function(x, book = TRUE) {
+    ch <- refs[which(refs[,1] == x),]
+    if (book) {
+        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
+    } else {
+        return(paste("Chapter~\\\\ref{", ch[2], "}", sep = ""))
+    }
+}
 
 
 ###################################################
 ### chunk number 2: ANOVA-weightgain-mean-var
 ###################################################
 data("weightgain", package = "HSAUR")
-tapply(weightgain$weightgain, list(weightgain$source, weightgain$type),
-mean)
-tapply(weightgain$weightgain, list(weightgain$source, weightgain$type),
-sd)
+tapply(weightgain$weightgain,
+       list(weightgain$source, weightgain$type), mean)
+tapply(weightgain$weightgain,
+       list(weightgain$source, weightgain$type), sd)
 
 
 ###################################################
@@ -46,7 +59,8 @@ summary(wg_aov)
 ###################################################
 ### chunk number 6: ANOVA-weightgain-iplot eval=FALSE
 ###################################################
-## interaction.plot(weightgain$type, weightgain$source, weightgain$weightgain)
+## interaction.plot(weightgain$type, weightgain$source,
+##                  weightgain$weightgain)
 
 
 ###################################################
@@ -55,7 +69,7 @@ summary(wg_aov)
 interaction.plot(weightgain$type, weightgain$source, weightgain$weightgain,
 legend = FALSE)
 legend(1.5, 95, legend = levels(weightgain$source), title = "weightgain$source",
-       lty = 1:2, bty = "n")
+       lty = c(2,1), bty = "n")
 
 
 ###################################################
@@ -73,8 +87,8 @@ options("contrasts")
 ###################################################
 ### chunk number 10: ANOVA-weightgain-coef-sum
 ###################################################
-coef(aov(weightgain ~ source + type + source:type, data = weightgain,
-     contrasts = list(source = contr.sum)))
+coef(aov(weightgain ~ source + type + source:type,
+    data = weightgain, contrasts = list(source = contr.sum)))
 
 
 ###################################################
@@ -142,7 +156,8 @@ plot(foster_hsd)
 ### chunk number 21: ANOVA-water-manova
 ###################################################
 data("water", package = "HSAUR")
-summary(manova(cbind(hardness, mortality) ~ location, data = water), test = "Hotelling-Lawley")
+summary(manova(cbind(hardness, mortality) ~ location,
+    data = water), test = "Hotelling-Lawley")
 
 
 ###################################################
@@ -156,7 +171,8 @@ tapply(water$mortality, water$location, mean)
 ### chunk number 23: ANOVA-skulls-data
 ###################################################
 data("skulls", package = "HSAUR")
-means <- aggregate(skulls[,c("mb", "bh", "bl", "nh")], list(epoch = skulls$epoch), mean)
+means <- aggregate(skulls[,c("mb", "bh", "bl", "nh")],
+                   list(epoch = skulls$epoch), mean)
 means
 
 
@@ -172,7 +188,8 @@ pairs(means[,-1],
 ###################################################
 ### chunk number 25: ANOVA-skulls-manova
 ###################################################
-skulls_manova <- manova(cbind(mb, bh, bl, nh) ~ epoch, data = skulls)
+skulls_manova <- manova(cbind(mb, bh, bl, nh) ~ epoch,
+                        data = skulls)
 summary(skulls_manova, test = "Pillai")
 summary(skulls_manova, test = "Wilks")
 summary(skulls_manova, test = "Hotelling-Lawley")
@@ -182,7 +199,7 @@ summary(skulls_manova, test = "Roy")
 ###################################################
 ### chunk number 26: ANOVA-skulls-manova2
 ###################################################
-summary.aov(manova(cbind(mb, bh, bl, nh) ~ epoch, data = skulls))
+summary.aov(skulls_manova)
 
 
 ###################################################
