@@ -4,7 +4,8 @@
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
 set.seed(290875)
-options(prompt = "R> ", width = 63, # digits = 4,
+options(prompt = "R> ", continue = "+  ",
+    width = 63, # digits = 4,
     SweaveHooks = list(leftpar = function()
         par(mai = par("mai") * c(1, 1.05, 1, 1))))
 HSAURpkg <- require("HSAUR")
@@ -13,6 +14,18 @@ rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
 a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
+book <- TRUE
+refs <- cbind(c("AItR", "SI", "CI", "ANOVA", "MLR", "GLM",
+                "DE", "RP", "SA", "ALDI", "ALDII", "MA", "PCA",
+                "MDS", "CA"), 1:15)
+ch <- function(x, book = TRUE) {
+    ch <- refs[which(refs[,1] == x),]
+    if (book) {
+        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
+    } else {
+        return(paste("Chapter~\\\\ref{", ch[2], "}", sep = ""))
+    }
+}
 
 
 ###################################################
@@ -81,16 +94,18 @@ y <- voting_mds$points[,2]
 plot(x, y, xlab = "Coordinate 1", ylab = "Coordinate 2",
      xlim = range(voting_mds$points[,1])*1.2, type = "n")
 text(x, y, labels = colnames(voting))
-voting_sh <- Shepard(voting[lower.tri(voting)], voting_mds$points)
+voting_sh <- Shepard(voting[lower.tri(voting)],
+                     voting_mds$points)
 
 
 ###################################################
 ### chunk number 10: MDS-voting-Shepard
 ###################################################
-library("MASS")
-voting_sh <- Shepard(voting[lower.tri(voting)], voting_mds$points)
-plot(voting_sh, pch = ".", xlab = "Dissimilarity", ylab = "Distance",
-     xlim = range(voting_sh$x), ylim = range(voting_sh$x))
+### library("MASS")
+### voting_sh <- Shepard(voting[lower.tri(voting)], voting_mds$points)
+plot(voting_sh, pch = ".", xlab = "Dissimilarity",
+     ylab = "Distance", xlim = range(voting_sh$x),
+     ylim = range(voting_sh$x))
 lines(voting_sh$x, voting_sh$yf, type = "S")
 
 
